Index: tests/corelib/date_time2_test.dart |
diff --git a/tests/corelib/date_time2_test.dart b/tests/corelib/date_time2_test.dart |
index 2004987e2542d782ff6ea3ebe069c6d01ae74eda..7982dee7f962331b2cf90b78a285f88c559881c8 100644 |
--- a/tests/corelib/date_time2_test.dart |
+++ b/tests/corelib/date_time2_test.dart |
@@ -2,13 +2,13 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
// Dart test program for Date's hashCode. |
main() { |
- var d = new Date.fromString("2000-01-01T00:00:00Z"); |
- var d2 = new Date.fromString("2000-01-01T00:00:01Z"); |
+ var d = new DateTime.fromString("2000-01-01T00:00:00Z"); |
+ var d2 = new DateTime.fromString("2000-01-01T00:00:01Z"); |
// There is no guarantee that the hashcode for these two dates is different, |
// but in the worst case we will have to fix this test. |
// The important test here is, that Date . |
Expect.isFalse(d.hashCode == d2.hashCode); |
} |
@@ -2,13 +2,13 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// Dart test program for Date's hashCode. |
+// Dart test program for DateTime's hashCode. |
main() { |
@@ -2,13 +2,13 @@ |
// There is no guarantee that the hashcode for these two dates is different, |
// but in the worst case we will have to fix this test. |
- // The important test here is, that Date . |
+ // The important test here is, that DateTime . |
Expect.isFalse(d.hashCode == d2.hashCode); |
} |